@@ -35,16 +35,17 @@ impl Default for Config {
 }
 
 impl Config {
-    /// Load the configuration file from either `path` or the default config dir
-    /// `${XDG_CONFIG_HOME}`.
+    /// Load the configuration file from either `path`, the default config dir `${XDG_CONFIG_HOME}`
+    /// or `/etc/xdg`.
     ///
     /// Error: File does not exist or can't be opened, syntax errors and other parsing errors.
     pub fn load(path: Option<PathBuf>) -> Result<Self, Error> {
         let cfg_path: PathBuf = if let Some(p) = path {
             p
         } else {
+            let sys_dir = PathBuf::from("/etc/xdg");
             dirs::config_dir()
-                .ok_or_else(|| format_err!("Can't access default config dir."))?
+                .unwrap_or(sys_dir)
                 .join(env!("CARGO_PKG_NAME"))
                 .join("config.toml")
         };
