@@ -5,10 +5,10 @@ use swayipc_async::Node;
 use crate::config::Config;
 
 fn filter_nodes(node: &Node) -> Vec<String> {
-    let ids = node
+    let mut ids: Vec<String> = node
         .nodes
         .iter()
-        .map(|n| {
+        .flat_map(|n| {
             let mut ids = filter_nodes(n);
             if let Some(props) = n.window_properties.as_ref() {
                 if let Some(class) = props.class.as_ref() {
@@ -20,8 +20,10 @@ fn filter_nodes(node: &Node) -> Vec<String> {
             }
             ids
         })
-        .flatten()
         .collect();
+    if let Some(app_id) = &node.app_id {
+        ids.push(app_id.clone());
+    }
     ids
 }
 
@@ -39,8 +41,7 @@ impl From<&Node> for AppIds {
         let mut floating = workspace
             .floating_nodes
             .iter()
-            .map(|n| filter_nodes(n))
-            .flatten()
+            .flat_map(filter_nodes)
             .collect();
         trace!("Floating app ids {:?}", floating);
         ids.append(&mut floating);
